﻿/**
 * Sample code for the GetPickupAvailability Canada Post service.
 * 
 * The GetPickupAvailability service identifies if pickup services 
 * are available for a given Postal Code. This call also provides information 
 * related to the type of pickup available and the cut-off times for pickup service 
 * requests.
 * 
 * This sample is configured to access the Developer Program sandbox environment. 
 * Use your development key username and password for the web service credentials.
 * 
 */

using System;
using System.ServiceModel.Channels;
using System.ServiceModel;
using System.Configuration;
using System.Security.Authentication;
using System.Net;

namespace GetPickupAvailability
{
    class GetPickupAvailability
    {
        //TLS 1.2 support for .NET 3.5
        public const SslProtocols _Tls12 = (SslProtocols)0x00000C00;
        public const SecurityProtocolType Tls12 = (SecurityProtocolType)_Tls12;

        static void Main(string[] args)
        {
            ServicePointManager.SecurityProtocol = Tls12;

            // Your username and password are imported from the following file
            // CPCWS_SOAP_Pickup_DotNet_Samples\SOAP\pickup\user.xml 
            var username = ConfigurationSettings.AppSettings["username"];
            var password = ConfigurationSettings.AppSettings["password"];

            PickupDomainPortTypeClient server = new PickupDomainPortTypeClient("PickupDomainPort", "https://ct.soa-gw.canadapost.ca/ad/soap/pickup/availability");
            server.ClientCredentials.UserName.UserName = username;
            server.ClientCredentials.UserName.Password = password;

            // Create Request

            getpickupavailabilityrequest request = new getpickupavailabilityrequest();
            request.locale = "FR";
            request.postalcode = "K2B8J6";
            
            // Disable timestamp on request
            BindingElementCollection elements = server.Endpoint.Binding.CreateBindingElements();
            elements.Find<SecurityBindingElement>().IncludeTimestamp = false;
            server.Endpoint.Binding = new CustomBinding(elements);

            String responseAsString = "";

            try
            {
                // Execute Request
                getpickupavailabilityresponse response = server.GetPickupAvailability(request);

                // Retrieve values from response object
                if (response.Item.GetType() == typeof(getpickupavailabilityresponsePickupavailability))
                {
                    getpickupavailabilityresponsePickupavailability pickUp = (getpickupavailabilityresponsePickupavailability)response.Item;
                    responseAsString += "Postal Code: " + pickUp.postalcode + "\r\n";
                    responseAsString += "On Demand Tour: " + pickUp.ondemandtour + "\r\n";
                    responseAsString += "On Demand Cut Off: " + pickUp.ondemandcutoff + "\r\n";                    
                }
                else
                {
                    messages msgs = (messages)response.Item;
                    foreach (var item in msgs.message)
                    {
                        responseAsString += "Error Code: " + item.code + "\r\n";
                        responseAsString += "Error Msg: " + item.description + "\r\n";
                    }
                }
            }
            catch (FaultException faultEx)
            {
                // SOAP Fault
                responseAsString += "Fault Code: " + faultEx.Code.Name + "\r\n";
                responseAsString += "Fault String: " + faultEx.Message + "\r\n";
            }
            catch (Exception ex) {
                // Misc Exception
                responseAsString += "ERROR: " + ex.Message + "\r\n";
            }
            
            Console.WriteLine(responseAsString);
            Console.WriteLine("Press any key to continue...");
            Console.ReadKey(true);        
           
        }
    }
}
